// (C) 2006 Jean-Francois Nifenecker - jean-francois.nifenecker@laposte.net
//
// -----------------------------------------------------------------------------
// LICENSE
// This software is released under the terms of the GNU LGPL.
// For more information, see the attaxhed License.txt file
// or http://www.gnu.org/licenses/lgpl.html
// -----------------------------------------------------------------------------
//
unit Options;

interface

type
  // the possible input options
  TOptions  = (optFileSpec,   // file(s) to process
              optQuiet,       // quiet: no output at all
              optHaltOnError, // requires the process to stop on first error
                              //  (otherwise will continue)
              optFileList,    // name of file containing the list of files to be processed
              optBackUp,      // backup required
              optBackupExt    // backup extension
              );

  TOption	=	class(TObject)
  private
    FType			: TOptions;
    FEnabled	: Boolean;
    FValue		: string;

  public
    property	OptionType:	TOptions read FType write FType;
    property	Enabled: Boolean read FEnabled write FEnabled;
    property	Value: string read FValue write FValue;
    
  end;// TOption

  TOptionArray	=	array[TOptions] of TOption;

const
  k_OptionStr : array[TOptions] of string = (
                '',   //  optFileSpec
                'Q',  //  optQuiet,
                'E',  //  optHaltOnError,
                'F',  //  optFileList
                'B',  //  optBackup
                'X'   //  optBackupExt
                );

var
  g_Options	:	TOptionArray;


function ParseParms: Boolean;
	// extract command-line options


//==============================================================================
implementation

uses
  SysUtils
  ;


function ParseParms: Boolean;

var
  l_Parm  : string;
  i       : Integer;

begin
Result	:=  True;

for i :=  1 to ParamCount do
  begin
  l_Parm  :=  Trim(ParamStr(i));

  if not (l_Parm[1] in ['-', '/'])
  then
    // file(s) to process
    begin
    g_Options[optFileSpec].Value  		:=	l_Parm;
    g_Options[optFileSpec].Enabled		:=	(Trim(g_Options[optFileSpec].Value) <> '');
    end
  else
    begin
    case  UpCase(l_Parm[2]) of

    //
    '?', 'H' :
      begin
      Result	:=	False;
      end;

    // options
    'Q' :
      begin
      g_Options[optQuiet].Enabled		:=	True;
      end;

    'F' :
      begin
      g_Options[optFileList].Enabled	:=	True;
      Delete(l_Parm, 1, 2);
      g_Options[optFileList].Value		:=	Trim(l_Parm);
      end;

    'X' :
      begin
      g_Options[optBackupExt].Enabled	:=	True;
      Delete(l_Parm, 1, 2);
      g_Options[optBackupExt].Value		:=	Trim(l_Parm);
      end;

    // switches
    'B' :
      begin
      if (l_Parm[3] = '+') then g_Options[optBackUp].Enabled	:=	True;
      if (l_Parm[3] = '-') then g_Options[optBackUp].Enabled	:=	False;
      end;

    'E' :
      begin
      if (l_Parm[3] = '+') then g_Options[optHaltOnError].Enabled	:=	True;
      if (l_Parm[3] = '-') then g_Options[optHaltOnError].Enabled	:=	False;
      end;

    else
      begin
      Result	:=	False;
      end;

    end;// case
    end;
  end;// for

if Result
then
  begin
  Result  :=  g_Options[optFileSpec].Enabled
              or
              g_Options[optFileList].Enabled
              ;
  end;

end;// ParseParms

procedure SetDefaultOptions;
begin
g_Options[optBackupExt].Enabled	:=	True;
g_Options[optBackupExt].Value		:=	'bak';
g_Options[optBackUp].Enabled	  :=	True;
end;// SetDefaultOptions

procedure InitOptions;

var
	l_OptType	:	TOptions;

begin
for l_OptType := Low(TOptions) to High(TOptions) do
	begin
  g_Options[l_OptType]	:=  TOption.Create;
  g_Options[l_OptType].OptionType	:=	l_OptType;
  g_Options[l_OptType].Enabled		:=	False;
  g_Options[l_OptType].Value			:=	'';
  end;// for
end;// InitOptions

procedure ReleaseOptions;

var
	l_OptType	:	TOptions;

begin
for l_OptType := High(TOptions) downto Low(TOptions) do
	begin
  g_Options[l_OptType].Free;
  end;// for
end;// ReleaseOptions


//==============================================================================
initialization
InitOptions;
SetDefaultOptions;

finalization
ReleaseOptions;

end.
